@@ -1,17 +1,13 @@
 ### This is a python package used for configuring a Morpheus appliance ###
 
-from .infra import (
-   groups
+from .infra.groups import (
+   infraGroup
 )
 
-from . import (
-   appliance
+from .appliance import (
+   morpheusAppliance
 )
 
-# from .appliance import (
-#    morpheusAppliance
-# )
-
 # from .configs import (
 #     createMorpheusGroup,
 #     createMorpheusAwsCloud,
